# Gemini Geometry Wars

**Geometry Wars** game with Google Gemini AI integrated into it.

# Source Code

The source code of **Gemini Geometry Wars** is available in [Source Code](https://github.com/SoftwareApkDev/gemini_geometry_wars/blob/master/gemini_geometry_wars/gemini_geometry_wars.py).

# Installation

```
pip install gemini_geometry_wars
```

# How to Run the Game?

Pre-requisites:

1. [Python](https://www.python.org/downloads/) installed in your device.
2. .env file in the same directory as <GEMINI_GEOMETRY_WARS_DIRECTORY> and has the value of GEMINI_API_KEY.

```
cd <GEMINI_GEOMETRY_WARS_DIRECTORY>
python gemini_geometry_wars.py
```

**Note:** Replace <GEMINI_GEOMETRY_WARS_DIRECTORY> with the path to the directory of the game **Gemini Geometry Wars**.

Then, the game will start like as follows.

![Game Start](images/Game_Start.png)

Once the user presses any key, the game will start.

![Gameplay](images/Gameplay.png)
